==> haskell-streaming-commons-0.2.2.6-26-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 streaming-commons
version:              0.2.2.6
visibility:           public
id:                   streaming-commons-0.2.2.6-4ZOdAHmSjPG6XiNhsEvYWl
key:                  streaming-commons-0.2.2.6-4ZOdAHmSjPG6XiNhsEvYWl
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  4d85f99ebe398984da9f20ca21938019
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

import-dirs:          /usr/lib/ghc-9.2.8/site-local/streaming-commons-0.2.2.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/streaming-commons-0.2.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-streaming-commons
hs-libraries:         HSstreaming-commons-0.2.2.6-4ZOdAHmSjPG6XiNhsEvYWl
depends:
    array-0.5.4.0 async-2.2.5-EP8h1wWlEwVFRsNBoUfgIV base-4.16.4.0
    bytestring-0.11.4.0 directory-1.3.6.2
    network-3.1.4.0-2VaTeXEywlqHC2pV2iXMik process-1.6.16.0
    random-1.2.1.2-JIamRYdFYdY4e3nutT9Pr4 stm-2.5.0.2 text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2
    zlib-0.6.3.0-7eb8DNb2CEF4EgehmrZW7c

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-streaming-commons-0.2.2.6-28-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 streaming-commons
version:              0.2.2.6
visibility:           public
id:                   streaming-commons-0.2.2.6-BYBDcyumTobELXYn1pU9hC
key:                  streaming-commons-0.2.2.6-BYBDcyumTobELXYn1pU9hC
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  89e61261660e994a8ba67e9de5b8a1b4
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

import-dirs:          /usr/lib/ghc-9.2.8/site-local/streaming-commons-0.2.2.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/streaming-commons-0.2.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-streaming-commons
hs-libraries:         HSstreaming-commons-0.2.2.6-BYBDcyumTobELXYn1pU9hC
depends:
    array-0.5.4.0 async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    bytestring-0.11.4.0 directory-1.3.6.2
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ process-1.6.16.0
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh stm-2.5.0.2 text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2
    zlib-0.6.3.0-AuZles6iZ6jGNBHTmlcghA

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
